Enum VisitMap
enum VisitMap<'de>
Integrate [Datetime][crate::Datetime] into an untagged deserialize
Variants
-
Datetime(crate::Datetime) The map was deserialized as a [Datetime][crate::Datetime] value
-
Key(alloc::borrow::Cow<'de, str>) The map is of an unknown format and needs further deserialization
Implementations
impl<'de> VisitMap<'de>
fn next_key_seed<V: serde::de::MapAccess<'de>>(visitor: &mut V) -> Result<Option<Self>, <V as >::Error>Determine the type of the map by deserializing it
impl<'de> Freeze for VisitMap<'de>
impl<'de> RefUnwindSafe for VisitMap<'de>
impl<'de> Send for VisitMap<'de>
impl<'de> Sync for VisitMap<'de>
impl<'de> Unpin for VisitMap<'de>
impl<'de> UnsafeUnpin for VisitMap<'de>
impl<'de> UnwindSafe for VisitMap<'de>
impl<T> Any for VisitMap<'de>
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for VisitMap<'de>
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for VisitMap<'de>
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> From for VisitMap<'de>
fn from(t: T) -> TReturns the argument unchanged.
impl<T, U> Into for VisitMap<'de>
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for VisitMap<'de>
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for VisitMap<'de>
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>