Struct DatetimeParseError
struct DatetimeParseError { ... }
Error returned from parsing a Datetime in the FromStr implementation.
Implementations
impl Clone for DatetimeParseError
fn clone(self: &Self) -> DatetimeParseError
impl Debug for DatetimeParseError
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl Display for DatetimeParseError
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl Error for DatetimeParseError
impl Freeze for DatetimeParseError
impl RefUnwindSafe for DatetimeParseError
impl Send for DatetimeParseError
impl Sync for DatetimeParseError
impl Unpin for DatetimeParseError
impl UnsafeUnpin for DatetimeParseError
impl UnwindSafe for DatetimeParseError
impl<T> Any for DatetimeParseError
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for DatetimeParseError
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for DatetimeParseError
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> CloneToUninit for DatetimeParseError
unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)
impl<T> From for DatetimeParseError
fn from(t: T) -> TReturns the argument unchanged.
impl<T> ToOwned for DatetimeParseError
fn to_owned(self: &Self) -> Tfn clone_into(self: &Self, target: &mut T)
impl<T> ToString for DatetimeParseError
fn to_string(self: &Self) -> String
impl<T, U> Into for DatetimeParseError
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for DatetimeParseError
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for DatetimeParseError
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>