Enum Offset
enum Offset
A parsed TOML time offset
Variants
-
Z A suffix which, when applied to a time, denotes a UTC offset of 00:00; often spoken "Zulu" from the ICAO phonetic alphabet representation of the letter "Z". --- RFC 3339 section 2
-
Custom { minutes: i16 } Offset between local time and UTC
Implementations
impl Clone for Offset
fn clone(self: &Self) -> Offset
impl Copy for Offset
impl Debug for Offset
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl Display for Offset
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl Eq for Offset
impl Freeze for Offset
impl Ord for Offset
fn cmp(self: &Self, other: &Offset) -> Ordering
impl PartialEq for Offset
fn eq(self: &Self, other: &Offset) -> bool
impl PartialOrd for Offset
fn partial_cmp(self: &Self, other: &Offset) -> Option<Ordering>
impl RefUnwindSafe for Offset
impl Send for Offset
impl StructuralPartialEq for Offset
impl Sync for Offset
impl Unpin for Offset
impl UnsafeUnpin for Offset
impl UnwindSafe for Offset
impl<T> Any for Offset
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for Offset
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for Offset
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> CloneToUninit for Offset
unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)
impl<T> From for Offset
fn from(t: T) -> TReturns the argument unchanged.
impl<T> ToOwned for Offset
fn to_owned(self: &Self) -> Tfn clone_into(self: &Self, target: &mut T)
impl<T> ToString for Offset
fn to_string(self: &Self) -> String
impl<T, U> Into for Offset
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for Offset
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for Offset
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>